#
# spec file for package checkmedia
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           checkmedia
Summary:        Check installation or Live media
License:        GPL-3.0-or-later
Group:          System/Management
Version:        6.3
Release:        150400.3.3.1
URL:            https://github.com/openSUSE/checkmedia
Source:         %{name}-%{version}.tar.xz
BuildRequires:  gpg
BuildRequires:  xz
BuildRequires:  rubygem(asciidoctor)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The program checks installation or Live media for errors.

%define libversion %(echo %version | cut -d. -f1)

%package -n     libmediacheck%{libversion}
Summary:        Library for checking installation or Live media
Group:          System/Libraries
Requires:       gpg

%description -n libmediacheck%{libversion}
Library for checking installation or Live media. Used by checkmedia and linuxrc.

%package -n     libmediacheck-devel
Summary:        Library for checking installation or Live media
Group:          Development/Libraries/C and C++
Requires:       libmediacheck%{libversion} = %version

%description -n libmediacheck-devel
Library for checking installation or Live media. Used by checkmedia and linuxrc.

%prep
%setup

%build
make %{?_smp_mflags}

%check
make test

%install
install -d -m 755 %{buildroot}/usr/bin
%make_install
make doc
install -D -m 644 checkmedia.1 %{buildroot}%{_mandir}/man1/checkmedia.1
install -D -m 644 tagmedia.1 %{buildroot}%{_mandir}/man1/tagmedia.1

%post -n libmediacheck%{libversion} -p /sbin/ldconfig

%postun -n libmediacheck%{libversion} -p /sbin/ldconfig

%files
%defattr(-,root,root)
/usr/bin/checkmedia
/usr/bin/tagmedia
%doc %{_mandir}/man1/checkmedia.*
%doc %{_mandir}/man1/tagmedia.*

%files -n libmediacheck%{libversion}
%defattr(-,root,root)
%{_libdir}/*.so.*
%doc README.*
%doc mediacheck.md
%if 0%{?suse_version} >= 1500
%license COPYING
%else
%doc COPYING
%endif

%files -n libmediacheck-devel
%defattr(-,root,root)
%{_libdir}/*.so
%{_includedir}/mediacheck.h

%changelog
* Tue Mar  5 2024 wfeldt@opensuse.org
- merge gh#openSUSE/checkmedia#18
- tagmedia: fix size detection for block devices (bsc#1220972)
- 6.3
* Fri Jun  2 2023 wfeldt@opensuse.org
- merge gh#openSUSE/checkmedia#17
- do not select EFI System Partition for digest calculation
  (bsc#1211953)
- use default for SKIPSECTORS only for RH media
- add man pages for checkmedia and tagmedia
- add spec file for OBS
- 6.2
* Tue Nov  9 2021 snwint@suse.com
- minor spec file adjustments
* Fri Oct  8 2021 wfeldt@opensuse.org
- merge gh#openSUSE/checkmedia#16
- fix auto-detecting a suitable signature location for rh media
  (jsc#SCL-6)
- 6.1
* Fri Oct  1 2021 wfeldt@opensuse.org
- merge gh#openSUSE/checkmedia#15
- add --version option to tagmedia
- use volume id if app id is missing for nice output
- add support for rh style meta data and digest calculation
- extend fragment calculation to suse style
- show signee if signature is ok
- add --create-signature option
- fix large file support
- updated unit tests
- enhance documentation
- add new and shiny README.adoc
- 6.0
* Wed Apr 15 2020 wfeldt@opensuse.org
- merge gh#openSUSE/checkmedia#14
- work better with broken media (bsc#1169420)
- 5.4
* Mon Jul 29 2019 wfeldt@opensuse.org
- merge gh#openSUSE/checkmedia#13
- mediacheck.md: fix typos
- 5.3
* Wed Jul 17 2019 wfeldt@opensuse.org
- merge gh#openSUSE/checkmedia#12
- fix compat issue with older gcc
- 5.2
* Wed Jul 17 2019 wfeldt@opensuse.org
- merge gh#openSUSE/checkmedia#11
- work also with older gpg versions
- 5.1
* Wed Jul 17 2019 jengelh@inai.de
- Use noun phrase in summaries.
- Drop redundant ldconfig PreReq.
* Tue Jul 16 2019 wfeldt@opensuse.org
- merge gh#openSUSE/checkmedia#10
- add support for signed media (bsc#1139561)
- adjust tagmedia script
- update doc
- adjust test cases
- add links to signature magic value origins
- allow to set specific gpg key for signature verification
- rearrange data structure to provide some compatibility
- check for empty signature
- better error log
- added tests for signature verification
- signature test results reference
- 5.0
* Wed Nov 28 2018 snwint@suse.de
- merge gh#openSUSE/checkmedia#8
- fix digest calculation in tagmedia (bsc#1117499)
- added testcases
- adjust function descriptions
- 4.1
* Fri Jun 29 2018 wfeldt@opensuse.org
- merge gh#openSUSE/checkmedia#6
- change tagmedia to also store checksum over partition
  (bsc#1000947)
- update Makefile
- update documentation
- rewrite checkmedia to use new mediacheck library
- digestdemo: add simple demo tool for libmediacheck usage
- mediacheck library header file
- mediacheck library code
- add test tool for mediachecks
- test data
- enhance code
- fix typo in tagmedia
- 4.0
* Thu Apr 26 2018 wfeldt@opensuse.org
- merge gh#openSUSE/checkmedia#5
- improve documentation
- fix Makefile
- update git2log script
- add simple usage examples
- 3.8
* Fri Dec  1 2017 wfeldt@opensuse.org
- merge gh#openSUSE/checkmedia#4
- determine image size correctly (bsc#1070745)
- more comments
- 3.7
* Tue Sep 12 2017 bwiedemann@suse.de
- merge gh#openSUSE/checkmedia#3
- sort input files (boo#1041090)
- 3.6
* Tue Sep 29 2015 snwint@suse.com
- Add information about openSUSE development
- Convert README to Markdown
- 3.5
* Tue Jan 27 2015 snwint@suse.com
- updated git2log script
- 3.4
* Tue Oct 14 2014 snwint_jenkins@suse.com
- added 'archive' Makefile target
- update git2log
- 3.3
* Wed Apr 30 2014 snwint@suse.de
- ignore padding area when calculating checksum (bnc#804160)
- 3.2
* Tue Nov  5 2013 snwint@suse.de
- added github url to spec
* Thu Oct 31 2013 dvaleev@suse.com
- make sure WORDS_BIGENDIAN is defined correctly where needed
* Wed Jan 25 2012 snwint@suse.de
- support more digests: md5, sha1, sha224, sha256, sha384, sha512
- changed license to gpl3
- new major version
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Wed Jul 13 2011 snwint@suse.de
- change isohybrid md5 calculation to report 'real' md5 sum (bnc#678739)
* Tue Oct 12 2010 snwint@suse.de
- don't check the first 512 bytes to avoid problems with isohybrid
* Tue Aug 25 2009 snwint@suse.de
- fixed tagmedia to use iso size from header
* Mon Oct  6 2008 snwint@suse.de
- report isos > 1GB as DVD (bnc#424323)
* Tue Jun  6 2006 snwint@suse.de
- add largefile support (#178812)
* Tue May  2 2006 snwint@suse.de
- perl's getopt is more picky now (#170322)
* Tue Mar 14 2006 snwint@suse.de
- align md5sum buffers (#157711)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Fri Dec 16 2005 snwint@suse.de
- support RH CDs
* Mon Sep 12 2005 snwint@suse.de
- big endian check was not active in md5.c (#116407)
* Wed Aug 17 2005 snwint@suse.de
- take padding into account
* Wed Aug 10 2005 snwint@suse.de
- tell test result in exit code (#102312)
* Fri Jul 22 2005 snwint@suse.de
- hopefully better DVD check (#74391)
* Thu Feb 10 2005 snwint@suse.de
- added tagmedia script
* Thu Jan 27 2005 snwint@suse.de
- indicate progress
* Mon Jan 24 2005 snwint@suse.de
- created package
